@@ -6,7 +6,7 @@ from aiohttp import web
 from jija import config
 
 from jija.middleware import Middleware
-from jija.utils.collector import collect_subclasses
+from jija.collector import collect_subclasses
 from jija.command import Command
 from jija import router
 
@@ -137,7 +137,9 @@ class App:
         aiohttp_app = aiohttp_app or web.Application()
 
         aiohttp_app.middlewares.extend(self.__middlewares)
+
         aiohttp_app.add_routes(self.__router.routes)
+        aiohttp_app['JIJA_ROUTER'] = self.__router
 
         return aiohttp_app
 
